@@ -146,6 +146,15 @@ class RunTimePaths(object):
             conf.get('script_dir',
                      os.path.join(self.host_root, 'scripts'))
 
+        self.host_storlet_python_lib_dir = ('/usr/local/lib/python2.7/'
+                                            'dist-packages/storlets')
+        self.sandbox_storlet_python_lib_dir = ('/usr/local/lib/python2.7/'
+                                               'dist-packages/storlets')
+        self.host_storlet_native_lib_dir = '/usr/local/lib/storlets'
+        self.sandbox_storlet_native_lib_dir = '/usr/local/lib/storlets'
+        self.host_storlet_native_bin_dir = '/usr/local/libexec/storlets'
+        self.sandbox_storlet_native_bin_dir = '/usr/local/libexec/storlets'
+
     def host_pipe_prefix(self):
         return os.path.join(self.host_pipe_root, self.scope)
 
@@ -225,7 +234,7 @@ class RunTimeSandbox(object):
         self.sandbox_wait_timeout = \
             int(conf.get('restart_linux_container_timeout', 3))
 
-        self.docker_repo = conf.get('docker_repo', 'localhost:5001')
+        self.docker_repo = conf.get('docker_repo', '')
         self.docker_image_name_prefix = 'tenant'
 
         # TODO(add line in conf)
@@ -316,13 +325,25 @@ class RunTimeSandbox(object):
 
         pipe_mount = '%s:%s' % (self.paths.host_pipe_prefix(),
                                 self.paths.sandbox_pipe_prefix)
-        storlet_mount = '%s:%s' % (self.paths.host_storlet_prefix(),
-                                   self.paths.sandbox_storlet_dir_prefix)
+        storlet_mount = '%s:%s:ro' % (self.paths.host_storlet_prefix(),
+                                      self.paths.sandbox_storlet_dir_prefix)
+        storlet_python_lib_mount = '%s:%s:ro' % (
+            self.paths.host_storlet_python_lib_dir,
+            self.paths.sandbox_storlet_python_lib_dir)
+        storlet_native_lib_mount = '%s:%s:ro' % (
+            self.paths.host_storlet_native_lib_dir,
+            self.paths.sandbox_storlet_native_lib_dir)
+        storlet_native_bin_mount = '%s:%s:ro' % (
+            self.paths.host_storlet_native_bin_dir,
+            self.paths.sandbox_storlet_native_bin_dir)
 
         cmd = [os.path.join(self.paths.host_restart_script_dir,
                             'restart_docker_container'),
                docker_container_name, docker_image_name, pipe_mount,
-               storlet_mount]
+               storlet_mount, storlet_python_lib_mount,
+               storlet_native_lib_mount, storlet_native_bin_mount]
+
+        self.logger.debug('About to start container %s' % cmd)
 
         return subprocess.call(cmd)
 
